@@ -209,7 +209,7 @@ class AbstractImage
 	virtual void event_leave_notify (){}
 
         virtual void configure() {} ;
-        virtual void createPicture() = 0;
+        virtual bool createPicture() = 0;
 };
 
 /*
@@ -283,8 +283,7 @@ class AbstractConfig
         virtual int getNumIcons() { return iconConfigList.size(); }
         virtual AbstractIconConfig * nextIcon()
         {
-            // TODO - use try and catch here to grab out-of-bounds errors
-            return iconConfigList[++iterCtr];
+            return ++iterCtr < iconConfigList.size() ? iconConfigList[iterCtr] : NULL;
         }
         virtual bool notFinished() { return iterCtr < iconConfigList.size(); }
 
