@@ -26,27 +26,61 @@
 #include "Util.h"
 #include "Misc.h"
 
-Database::Database() : blankTable()
-{
-    File = "";
+#include <algorithm> 
+#include <functional> 
+#include <cctype>
+#include <locale>
+
+// trim from start
+static inline std::string &ltrim(std::string &s) {
+        s.erase(s.begin(), std::find_if(s.begin(), s.end(), std::not1(std::ptr_fun<int, int>(std::isspace))));
+        return s;
 }
 
-Database::Database( string  F ) : blankTable()
+// trim from end
+static inline std::string &rtrim(std::string &s) {
+        s.erase(std::find_if(s.rbegin(), s.rend(), std::not1(std::ptr_fun<int, int>(std::isspace))).base(), s.end());
+        return s;
+}
+
+// trim from both ends
+static inline std::string &trim(std::string &s) {
+        return ltrim(rtrim(s));
+}
+
+Database::Database( string  F, bool fallbackToDefaultRc ) : blankTable()
 {
+    wasLoaded = false;
     ifstream DbFile;
-    DbFile.open(F.c_str(),ios::in);
+    DbFile.open(F.c_str(), ios::in);
     
     if (!DbFile.is_open()) {
-        cout << "Cannot load file: " << F << "!! \n";
-	string defaults = string(DEFAULT_PREFIX) + "/share/" + string(PACKAGE) + "/dot.ideskrc";
-	Util::copy(defaults,F);
-	DbFile.clear();
-	DbFile.open(F.c_str(),ios::in);
-	if (!DbFile.is_open()) {
-		cout << "Cannot load file: " << F << "!! Exiting.\n";
-		_exit(1);
-	}
-	
+        if (!fallbackToDefaultRc) {
+            cerr << "Cannot read file: " << F << "\n";
+            _exit(1);
+        }
+
+        cerr << "Cannot read file: " << F << "\nUsing embedded defaults\n";
+
+        //TODO: add all defaults here
+        {
+        Table & T = AddTable( "Config" );
+        T.Set("FontName", "Arial");
+        T.Set("FontSize", "10");
+        T.Set("FontColor", "#000000");
+        }
+
+        {
+        Table & T = AddTable( "Actions" );
+        T.Set("Lock", "control right doubleClk");
+        T.Set("Reload", "middle doubleClk");
+        T.Set("Drag", "left hold");
+        T.Set("EndDrag", "left singleClk");
+        T.SetArray("Execute", "left doubleClk", 0);
+        T.SetArray("Execute", "right doubleClk", 1);
+        }
+
+        return;
     }
 
     string Buffer, Line, temp;
@@ -91,13 +125,15 @@ Database::Database( string  F ) : blankTable()
 		    //cout << "Buffer:'" << Buffer	<< "'" << endl;
 			if (Line.size()>0){
 				Line = Line.substr( 1, Line.size()-1 );
-				if(getUpper(Buffer) == "ICON"){ //remove all white spaces to filename
+/*				if(getUpper(Buffer) == "ICON")
+				{
+					//remove all white spaces to filename
 					int pos = Line.find(' ', 0); 
 					if( pos != string::npos){ //search for white spaces from the end
 						Line =   Line.substr( 0 , pos); 
-					}	    
-					//cout << "Line:'"<< Line <<"'" <<endl;
-				}
+					}
+					cout << "Line:'"<< Line <<"'" <<endl;
+				} */
 			}
                      else
                         Line = "";
@@ -109,7 +145,9 @@ Database::Database( string  F ) : blankTable()
         }
     }
     DbFile.close();
-   // print();
+    // print();
+
+    wasLoaded = true;
 }
 
 Database::~Database()
@@ -147,7 +185,7 @@ void Database::Write(const string file)
 void Database::Write( ) {
     ofstream DbFile( File.c_str() );
     if (!DbFile) {
-        cout << "Cannot load file: " << File << "!! Exiting.\n";
+        cerr << "Cannot write file: " << File << "\nExiting\n";
         _exit(1);
     }
 
@@ -178,10 +216,10 @@ Table::Table( const string & T ) {
 
 void Table::print()
 {
-    cout << "Table: " << Title << endl;
+    cerr << "Table: " << Title << endl;
     for (int i=0; i < Label.size(); i++)
-        cout << "  " << Label[i] << ": " << Value[i] << endl;
-    cout << "End Table\n";
+        cerr << "  " << Label[i] << ": " << Value[i] << endl;
+    cerr << "End Table\n";
 
 }
 
@@ -191,13 +229,26 @@ bool Table::isValid()
 }
 
 
+void Table::Set( const string & L, string & V ) {
+    if( Query(L) == "" ) {
+        Label.push_back( L );
+        Value.push_back( V );
+    } else {
+        for(unsigned int i=0; i<Label.size(); i++ )
+            if( Label[i] == L ) Value[i] = trim(V);
+    }         
+}             
+
 void Table::Set( const string & L, const string & V ) {
     if( Query(L) == "" ) {
         Label.push_back( L );
         Value.push_back( V );
     } else {
         for(unsigned int i=0; i<Label.size(); i++ )
-            if( Label[i] == L ) Value[i] = V;
+            if( Label[i] == L ) {
+				Value[i] = V;
+				break;
+			}
     }         
 }             
 
