@@ -2,6 +2,7 @@
  * 
  * Idesk -- DesktopIconConfig.cpp
  *
+ * Copyright (c) 2013 neagix
  * Copyright (c) 2002, Chris (nikon) (nikon@sc.rr.com)
  * All rights reserved.
  *
@@ -24,7 +25,7 @@
 
 #include "DesktopIconConfig.h"
 
-DesktopIconConfig::DesktopIconConfig(const string & fName, CommonOptions * parentData)
+DesktopIconConfig::DesktopIconConfig(const string & fName, Table &table, CommonOptions * parentData)
 {
     iconFilename = fName;
     
@@ -32,16 +33,8 @@ DesktopIconConfig::DesktopIconConfig(const string & fName, CommonOptions * paren
     
     common->setDefaultsFromParent(*parentData);
 
-    Database db(iconFilename);
-    Table table = db.Query("Icon");
-
-    if(!table.isValid())
-        cout << "No Icon table found in the config file!!\n";
-    else
-    { 
-        common->setOptions(table); 
-        setIconOptions(table);
-    }
+    common->setOptions(table);
+    setIconOptions(table);
 }
 
 DesktopIconConfig::~DesktopIconConfig()
@@ -70,7 +63,7 @@ void DesktopIconConfig::saveIcon(int xCord, int yCord)
     x = xCord;
     y = yCord;
 
-    Database db(iconFilename);
+    Database db(iconFilename, false);
     Table & table = db.Query("Icon");
     
     if(table.isValid())
@@ -80,7 +73,6 @@ void DesktopIconConfig::saveIcon(int xCord, int yCord)
         
         db.Write();
     }
-
 }
 
 string DesktopIconConfig::getExtension(const string & file)
@@ -92,7 +84,7 @@ string DesktopIconConfig::getExtension(const string & file)
         pos == (file.size() - 1) || // '.' is at end of string
         pos == file.size() )        // '.' is at beginning of string 
     {
-        cout << "Cannot determine file extension of: " << file << endl;
+        cerr << "Cannot determine file extension of: " << file << endl;
         returnString = "?";
     }
     else  //grab all of the string that is after the '.'
@@ -143,7 +135,7 @@ void CommonOptions::setCommonDefaults()
     
     fillStyle = "None";
     
-    cursorOver = XC_hand1;
+    cursorOver = XC_top_left_arrow;
 }
 
 void CommonOptions::setDefaultsFromParent(CommonOptions & other)
