@@ -87,7 +87,7 @@ void XDesktopContainer::initXWin()
     display = XOpenDisplay(NULL);
     
     if (!display){
-	 cout << "Display is null!!\n";
+	 cerr << "Display is null!\n";
 	 _exit(1);
     }
     
@@ -97,7 +97,7 @@ void XDesktopContainer::initXWin()
      
      XTextProperty prop;
      Atom start = XInternAtom(display,"_IDESK_START", false);
-     cout << " Idesk starting in " <<  name << endl;
+     cerr << "[Idesk] Starting on display " <<  name << endl;
      prop.value = (unsigned char *)name;
      prop.encoding = XA_STRING;
      prop.format = 8;
@@ -135,21 +135,23 @@ void XDesktopContainer::getRootImage()
      }
 }
 
+inline bool fileExists (const std::string& name) {
+  struct stat buffer;   
+  return (stat (name.c_str(), &buffer) == 0); 
+}
+
 void XDesktopContainer::configure()
-{    
+{
     //get the user's config file
-    string ideskrcFile = getenv("HOME");
-    ideskrcFile += "/.ideskrc";
+    string homeDirectory = getenv("HOME");
+    string ideskrcFile = homeDirectory + "/.config/idesktop/ideskrc";
+    if (!fileExists(ideskrcFile))
+        ideskrcFile = homeDirectory + "/.ideskrc";
 
-    Database db(ideskrcFile);
-    config = new DesktopConfig(db, ideskrcFile);
+    Database db(ideskrcFile, true);
+    DesktopConfig * dConfig = new DesktopConfig(db, ideskrcFile);
+    config = dConfig;
     
-    DesktopConfig * dConfig = dynamic_cast<DesktopConfig *>(config);
-    
-    if(config->numIcons() == 0){
-	    dConfig->loadDefaultIcons();
-    }
-
     locked = dConfig->getLocked();
     clickDelay = dConfig->getClickSpeed();
 
@@ -167,32 +169,24 @@ void XDesktopContainer::loadIcons()
 
     if (config->numIcons() == 0)
     {
-        cout << "No icons loaded!! .idesktop is empty or contains invalid icons\n";
-        _exit(1);
+        return;
     }
-    else
-    {
-        //iterate through all the icons created by the configure class
-        for(iconPtr = config->start(); config->notFinished();
-            iconPtr = config->nextIcon())
-        {
-            DesktopIconConfig * dIconConfig =
-                dynamic_cast<DesktopIconConfig *>(iconPtr);
 
-            XIcon * icon;
-            if (dIconConfig->getSnapShadow() && dIconConfig->getSnapShadow()){
-                icon = new XIconWithShadow(this, config, iconPtr);
-	    }
-            else{
-                icon = new XIcon(this, config, iconPtr);
-		
-	}
-	if (icon->isValid()){
-		if(icon->createIcon()){
-	    		   addIcon(icon);
+    // iterate through all the icons created by the configure class
+    for(iconPtr = config->start(); config->notFinished();
+        iconPtr = config->nextIcon()) {
+        DesktopIconConfig * dIconConfig = dynamic_cast<DesktopIconConfig *>(iconPtr);
+
+        XIcon * icon;
+        if (dIconConfig->getSnapShadow() && dIconConfig->getSnapShadow()) {
+            icon = new XIconWithShadow(this, config, iconPtr);
+	    } else {
+            icon = new XIcon(this, config, iconPtr);
 		}
-	}
-      }
+	    if (icon->isValid()){
+		    if (icon->createIcon())
+	    	    addIcon(icon);
+	    }
     }
 }
 
@@ -203,8 +197,7 @@ void XDesktopContainer::arrangeIcons()
 
     if( iconList.size() == 0 )
     {
-        cout << "No Icons! Quitting.\n";
-        _exit(1);
+        return;
     }
 
     for(unsigned int i = 0; i < iconList.size(); i++ )
@@ -345,8 +338,8 @@ void XDesktopContainer::parseNonIconEvents()
 				string mesg = (char *)prop.value;
 				if(current_display_name == old_display_name){
 					XDeleteProperty (display, rootWindow, atom_stop);
-					cout << "Error ... Idesk is running in " << prop.value << endl;
-					cout << "Exit." << endl;
+					cerr << "Error ... Idesk is running in " << prop.value << endl;
+					cerr << "Exit." << endl;
 					_exit(1);
 				}
 			}
@@ -588,21 +581,25 @@ void XDesktopContainer::reloadState()
 
 void XDesktopContainer::runCommand(const string & command)
 {
-     pid_t pid;   
-    //fork and execute program
-    if (pid=fork() != 0) { //Primer proceso hijo
+    pid_t pid;
+    // fork and execute program by replacing child's process
+    pid = fork();
+    if (pid == 0) {
 #ifdef HAVE_STARTUP_NOTIFICATION
 	    if (sn_context != NULL)
 		     sn_launcher_context_setup_child_process (sn_context);
 #endif /* HAVE_STARTUP_NOTIFICATION  */
                 setsid();
-		if(execl("/bin/sh", "/bin/sh", "-c", command.c_str(), 0) == -1){
-			printf("Error to execute command %s\n", command.c_str());
+		if (execl("/bin/sh", "/bin/sh", "-c", command.c_str(), (char *)0) == -1) {
+			fprintf(stderr, "Error to execute command '%s': %s\n", command.c_str(), strerror(errno));
 			exit(1);
 		}
-		exit(0); //exit fork
+		// this line is never reached
+    } else if (pid < 0) {
+        fprintf(stderr, "Failed to fork process to run command '%s': %s\n", command.c_str(), strerror(errno));
+    } else {
+        waitpid(pid, NULL, 0);
     }
-    waitpid(pid, NULL, 0);
 }
 int XDesktopContainer::widthOfScreen()
 {
