@@ -109,7 +109,7 @@ void XImlib2ToolTip::createFont()
 		 XftTypeDouble,
 		 (double)dConfig->getFontSizeTip(), 
 		 XFT_WEIGHT, XftTypeInteger, XFT_WEIGHT_MEDIUM,
-		 NULL );
+		 (void *)NULL );
 
     XftTextExtentsUtf8(display, tooltip.font, (XftChar8*)tipText.c_str(), tipText.length(), &fontInfo );
     
@@ -127,9 +127,8 @@ Window XImlib2ToolTip::getWindow()
   return tooltip.window;
 }
 
-void XImlib2ToolTip::event_enter_notify ()
+void XImlib2ToolTip::draw_caption()
 {
-	if(captionTipOnHover && tipText.length() > 0){ 
 		int fX, fY;		 
 		setXY(fX, fY, width, height);
 		
@@ -140,6 +139,12 @@ void XImlib2ToolTip::event_enter_notify ()
 		XSetFillStyle(display, tooltip.gc, FillTiled);
 		XSetTile(display, tooltip.gc, pixmap);
 		XFillRectangle(display, pixmap, tooltip.gc, 0, 0, width, height);
+}
+
+void XImlib2ToolTip::event_enter_notify ()
+{
+	if(captionTipOnHover && tipText.length() > 0){
+		draw_caption();
 	}	
 }
 
